package geo;

import geo.basics.Point;

/** Movable and resizable circle in a two-dimensional coordinate-system.
 */
public class Circle {

    /**Centerpoint of the circle.*/
    public Point cp;

    /** Radius of the circle*/
    private double r;

    /** Area of the circle*/
    private double area = r*r*Math.PI;
  
    /** Tolerance in case of floating point caclulations*/
    private static double delta = 0.01;  

    /**Constructs a circle with the given centerpoint and radius.*/
    public Circle(Point p, double r) {
        this.cp = p;
        setR(r);
    }

    /**
     * Constructs a circle with a new centerpoint in coordinate (x,y)
     * with and the given radius.
     */
    public Circle(int x, int y, double r) {
        this(new Point(x,y), r);
    }

    /**
     * Constructs a circle with a new default centerpoint and with the
     * given radius.
     */
    public Circle(double r) {
        this(new Point(), r);
    }

    /**
     * Constructs a circle with a new default centerpoint and with
     * radius 1.
     */
    public Circle() {
        this(1);
    }

    public static void setDelta(double d) {
        delta = d;
    }

    public static double getDelta() {
        return delta;
    }

    public void setR(double r) {
        this.r = r;
        area = r*r*Math.PI;
    }

    public double getR() {
        return r;
    }

    public double getArea() {
        return area;
    }

    public void shift(int dx, int dy) {
        cp.shift(dx, dy);
    }

    public void enlarge(double factor) {
        setR(r *= factor);
    }

    public void toCenterPoint(Point p) {
        cp = p;
    }

    /**
     * Decide whether the given point is lie on the circle line or
     * not.
     */
    public boolean isLieOn(Point p) {
        return delta > Math.abs(Point.distance(cp, p) - r);
    }

    public String toString() {
        return "cp:" + cp + " r:" + r;
    }
}