package geo.basics;

/**
 * Movable point in a two-dimensional coordinate-system.
 */
public class Point {

    /** Calculates the distance of the given two points.
     */
    public static double distance(Point p1, Point p2) {
        return Math.hypot(p1.x-p2.x,p1.y-p2.y); 
    }

    /** x coordinate of the point*/
    public int x;
    /** y coordinate of the point*/
    public int y;

    /**Consturcts a new point in the origo of the coordinate system.*/
    public Point() {
        this(0,0);
    }
    
    /**
     * Constructs a new point with the given coordinates.
     * @param x First (x) coordinate of the point.
     * @param y Second (y) coordinate of the point.
     */    
    public Point(int x, int y) {
        this.x = x;
        this.y = y;
    }

    /** Shifts the point.
     * @param x Shift amount along the x axis.
     * @param y Shift amount along the y axis.
     */
    public void shift(int x, int y) {
        this.x += x;
        this.y += y;
    }

    /** Shifts the point with equal amount along x and y axis.
     * @param x Shift amount.
     */
    public void shift(int x) {
        shift(x,x);
    }

    /**
     * Calculates the distance of the given point from our actual
     * point.
     */
    public double distance(Point p) {
        return Point.distance(this, p);
    }

    /** Returns with the String repesentation of the point.
     */
    public String toString() {
        return "(" + x + "," + y + ")";
    }

}